@@ -9,7 +9,7 @@ use RDF::aREF;
 use RDF::aREF::Encoder;
 use RDF::NS;
 
-our $VERSION = '0.16';
+our $VERSION = '0.19';
 
 with 'Catmandu::RDF';
 with 'Catmandu::Importer';
@@ -30,10 +30,15 @@ has encoder => (
     is      => 'ro',
     lazy    => 1,
     builder => sub {
-        RDF::aREF::Encoder->new( ns => $_[0]->ns );
+        my $ns = $_[0]->ns;
+        RDF::aREF::Encoder->new( ns => (($ns // 1) ? $ns : { }) );
     }
 );
 
+has triples => (
+    is      => 'ro',
+);
+
 sub generator {
     my ($self) =@_;
     sub {
@@ -41,27 +46,44 @@ sub generator {
         return unless $stream;
 
         my $aref;
-        $stream = $stream->as_hashref;
-        # TODO if size = 1 use _id => $key
-        # TODO: include namespace mappings if requested
-        while (my ($s,$ps) = each %$stream) {
-            foreach my $p (keys %$ps) {
-                my $predicate = $self->encoder->predicate($p);
-               $stream->{$s}->{$predicate} = [
-                    map { $self->encoder->object($_) } @{$stream->{$s}->{$p}} 
-                ]; 
-                delete $stream->{$s}->{$p} if $predicate ne $p;
+
+        if ($self->triples) {
+            if (my $triple = $stream->next) {
+                # TODO: move to RDF::aREF
+                my $subject = $triple->subject->is_resource 
+                            ? $triple->subject->uri_value 
+                            : $triple->subject->sse; # blank
+                return {
+                    _id => $triple->subject->uri_value,
+                    $self->encoder->predicate($triple->predicate->uri_value),
+                    $self->encoder->object($triple->object)
+                };
+            } else {
+                return ($stream = undef);
             }
+        } else {
+
+            $stream = $stream->as_hashref;
+            # TODO if size = 1 use _id => $key
+            # TODO: include namespace mappings if requested
+            while (my ($s,$ps) = each %$stream) {
+                foreach my $p (keys %$ps) {
+                    my $predicate = $self->encoder->predicate($p);
+                   $stream->{$s}->{$predicate} = [
+                        map { $self->encoder->object($_) } @{$stream->{$s}->{$p}} 
+                    ]; 
+                    delete $stream->{$s}->{$p} if $predicate ne $p;
+                }
+            }
+            $aref = $stream;
+            $stream = undef;
+
+            if ($self->url) {
+                $aref->{_url} = $self->url;
+            }
+
+            return $aref;
         }
-        $aref = $stream;
-
-        if ($self->url) {
-            $aref->{_url} = $self->url;
-        }
-
-        $stream = undef;
-
-        return $aref;
     };
 }
 
@@ -75,10 +97,15 @@ sub _rdf_stream {
     if ($self->url) {
         $parser->parse_url_into_model( $self->url, $model );
     } else {
-        if (defined $self->file and !$self->type) { 
+        my $from_scalar = (ref $self->file // '') eq 'SCALAR';
+        if (!$self->type and $self->file and !$from_scalar) {
             $parser = $parser->guess_parser_by_filename($self->file);
         }
-        $parser->parse_file_into_model( $self->base, $self->file // $self->fh, $model );
+        if ($from_scalar) {
+            $parser->parse_into_model( $self->base, ${$self->file}, $model );
+        } else {
+            $parser->parse_file_into_model( $self->base, $self->file // $self->fh, $model );
+        }
     }
     
     return $model->as_stream;
@@ -95,7 +122,7 @@ Catmandu::Importer::RDF - parse RDF data
 
 Command line client C<catmandu>:
 
-    catmandu convert RDF --url http://d-nb.info/1001703464 to YAML
+    catmandu convert RDF --url http://d-nb.info/gnd/4151473-7 to YAML
     catmandu convert RDF --file rdfdump.ttl to JSON
 
 In Perl code:
@@ -144,6 +171,10 @@ Use default namespace prefixes as provided by L<RDF::NS> to abbreviate
 predicate and datatype URIs. Set to C<0> to disable abbreviating URIs.
 Set to a specific date to get stable namespace prefix mappings.
 
+=item triples
+
+Import each RDF triple as one aREF predicate map, if enabled.
+
 =back
 
 =head1 METHODS
@@ -152,7 +183,7 @@ See L<Catmandu::Importer>.
 
 =head1 SEE ALSO
 
-L<RDF::Trine::Store>, L<RDF::Trine::Parsers>
+L<RDF::Trine::Store>, L<RDF::Trine::Parser>
 
 =encoding utf8
 
